@@ -19,14 +19,14 @@ import sys
 
 from rich.console import Console
 
-console = Console(width=120)
+CONSOLE = Console(width=120)
 
 
 def check_ffmpeg_installed():
     """Checks if ffmpeg is installed."""
     ffmpeg_path = shutil.which("ffmpeg")
     if ffmpeg_path is None:
-        console.print("[bold red]Could not find ffmpeg. Please install ffmpeg.")
+        CONSOLE.print("[bold red]Could not find ffmpeg. Please install ffmpeg.")
         print("See https://ffmpeg.org/download.html for installation instructions.")
         print("ffmpeg is only necessary if using videos as input.")
         sys.exit(1)
@@ -36,6 +36,6 @@ def check_colmap_installed():
     """Checks if colmap is installed."""
     colmap_path = shutil.which("colmap")
     if colmap_path is None:
-        console.print("[bold red]Could not find COLMAP. Please install COLMAP.")
+        CONSOLE.print("[bold red]Could not find COLMAP. Please install COLMAP.")
         print("See https://colmap.github.io/install.html for installation instructions.")
         sys.exit(1)
